@@ -1,7 +1,7 @@
 /* -*-pgsql-c-*- */
 /*
  *
- * $Header: /home/t-ishii/repository/pgpool/pool.h,v 1.4 2003/06/27 08:30:36 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool.h,v 1.6 2003/07/20 14:44:37 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -28,8 +28,16 @@
 
 #include "config.h"
 #include <stdio.h>
+#include <time.h>
 
-/* undef this on FreeBSD */
+/* 
+ * define this if you do not want to issue RESET ALL at each new
+ * connection.  Also you need to define this for 7.1 or prior
+ * PostgreSQL since they do not support RESET ALL
+ */
+#undef NO_RESET_ALL
+
+/* undef this if you have problems with non blocking accept() */
 #define NONE_BLOCK
 
 #define POOLMAXPATHLEN 8192
@@ -95,8 +103,31 @@ typedef struct {
     int pid;	/* backend pid */
     int key;	/* cancel key */
     POOL_CONNECTION	*con;
+	time_t closetime;	/* absolute time in second when the connection closed */
 } POOL_CONNECTION_POOL;
 
+/*
+ * startup packet definitions stolen from PostgreSQL
+ */
+#define SM_DATABASE		64
+#define SM_USER			32
+#define SM_OPTIONS		64
+#define SM_UNUSED		64
+#define SM_TTY			64
+
+typedef struct StartupPacket
+{
+	int			protoVersion;		/* Protocol version */
+	char		database[SM_DATABASE];	/* Database name */
+	char		user[SM_USER];	/* User name */
+	char		options[SM_OPTIONS];	/* Optional additional args */
+	char		unused[SM_UNUSED];		/* Unused */
+	char		tty[SM_TTY];	/* Tty for debug output */
+} StartupPacket;
+
+#define Max(x, y)		((x) > (y) ? (x) : (y))
+#define Min(x, y)		((x) < (y) ? (x) : (y))
+
 /*
  * global variables
  */
@@ -139,4 +170,7 @@ extern POOL_STATUS ErrorResponse(POOL_CONNECTION *frontend,
 
 void notice_backend_error(void);
 
+void pool_connection_pool_timer(POOL_CONNECTION_POOL *backend);
+RETSIGTYPE pool_backend_timer_handler(int sig);
+
 #endif /* POOL_H */
